==> fluxbox-0.9.12.tar.bz2: fluxbox-0.9.12/nls/pl_PL/Translation.m <==
$ codeset=ISO-8859-2

$set 1 #Align

1 Dolny rodkowy
2 Dolny Lewy
3 Dolny Prawy
4 Poziomo
5 Z Lewej
6 Dolny Lewy
7 rodkowy Lewy
8 Grny Lewy
9 Wzgldny
10 Z Prawej
11 Dolny Prawy
12 rodkowy Prawy
13 Prawy Grny
14 Grny rodkowy
15 Grny Lewy
16 Grny Prawy
17 Pionowo

$set 2 #BaseDisplay

1 Porzucam...Zrzucam pami\n
2 Zamykam\n
3 %s:    sygna %d otrzyma\n

$set 3 #Common
1 Przeroczysto
2 Auto ukrywanie
3 Skompilowano
4 Skompilowano z opcjami
5 Kompilator
6 Wersja kompilatora
7 init
8 keys
9 menu
10 Styl
11 Wartoci domylne
12 wyczone
13 Bd
14 Fluxbox wersja
15 Maksymalizuj nad
16 Widoczny



$set 4 #Configmenu

1 AntiAlias
2 Automatyczne podnoszenie
3 Kliknij aby da na wierzch
4 Kliknij by uaktywni
5 Dekoracje na oknach-dzieciach
6 Zmiana pulpitw kkiem myszy
7 Zmie aktywne okno przy zmianie pulpitw
8 Sposb aktywacji okien
9 Ustawiaj nowe okna jako aktywne
10 Pena maksymalizacja
11 Rastrowanie Obrazu
12 Wywietlaj zawarto przesuwanego okna
13 P-automatyczna aktywacja
14 Poka kursorem by uaktywni
15 Pulpity obok siebie

16 Wymu pseudo przeroczysto
17 Przeroczysto menu
18 Przeroczysto
19 Przeroczysto aktywnego okna
20 Przeroczysto nieaktywnego okna

$set 5 #Ewmh

1 Bd krytyczny: Brak pamici, nie mog zarezerwowa lity klientw EWMH

$set 6 #FbTkError

1 Ostrzeenie! Wysoko > 3200 Ustawiam Wysoko = 3200
2 Ostrzeenie! Szeroko > 3200 Ustawiam Szeroko = 3200
3 Ostrzeenie: nie mog zaadowa zapasowej czcionki
4 Bd allokacji.
5 Bd podczas tworzenia pixmapy
6 Nie mog stworzy XImage
7 Bd odczytu
8 Ostrzeenie: Nie znaleziono poprawnych ustawie przeroczystoci
9 Ostrzeenie: Nie powiodo si tworzenie przeroczystego obrazu
10 Ostrzeenie: Nie powiodo si tworzenie przeroczystej pixmapy 
11 Nie znalaem formatu dla ekranu(%d)
12 Brak pamici
13 Brak pamici podczas alokacji niebieskiego bufora.
14 Brak pamici podczas alokacji zielonego bufora.
15 Brak pamici podczas alokacji czerwonego bufora.
16 Nie rozpoznaj elementu stylu
17 bd podczas renderowania obrazka
18 Ustawiam warto domyln

$set 7 #Fluxbox

1 niewasciwa nazwa pliku zasobw!
2 Nie mog zaadowa pliku grup
3 Nie mog zaadowa bazy danych
4 Prbuje ponownie z
5 Ostrzeenie! Nie mog znale ekranu na ktry mog zmapowa okno!
6 Nie mog utworzy katalogu %s
7 Nie moge znale ekranw do zarzdzania\nUpewnij si e nie masz wczonego inne menedera okien.
8 Bd podczas parsowania wyraenia reguralnego
9 Bd krytyczny! Moe istnie tylko jedna instancja klasy fluxbox.
10 Nie mog poczy si z serwerem X.\nUpewnij si e uruchomie X'y przed uruchomieniem Fluxbox.
11 Ostrzeenie: serwer X nie wspiera ustawie lokalnych
12 Ostrzeenie: nie mona ustawi modyfikatorw lokalnych

$set 8 #Gnome

1 Bd krytyczny: Brak pamici, nie mog zaalokowa dla listy klientw GNOME

$set 9 #Keys

1 Keys: Bd w lini
2 Keys: Bd podczas czenia drzew klawiszy!
3 Keys: Niewaciwy klawisz/modyfikator w linii

$set 10 #Menu

1 Konfiguracja
2 Domylne menu fluxbox
3 Wyjcie
4 Ikonki
5 Warstwa...
6 Na monitorze...
7 Umiejscowienie
8 Przeaduj ustawienia
9 Restart
10 xterm


$set 11 #Remember

1 Dekoracje
2 Rozmiar
3 Przejd do pulpitu
4 Warstwa
5 Zapamitaj
6 Pozycja
7 Zapisz przy wyjciu
8 Zwinity
9 Przyklejony
10 Nieznany klucz pliku apps
11 Pulpit

12 Monitor

$set 12 #Screen

1 BScreen::BScreen: wystpi bd podczas wysyania zapytania do serwera X'w.\nNa ekranie wczony jest ju inny meneder okien
2 S: %4d x W: %4d

4 BScreen::BScreen: uywanie ekrany %d uywam visuala 0x%lx, gboko %d\n
5 X: %4d x Y: %4d
6 0: 0000 x 0: 0000


$set 13 #Slit

1 Klienci
2 Przesu wszystkich w gr
3 Przesu wszystkich w d
4 Kierunek Tacki
5 Warstwa
6 Na monitorze
7 Pooenie Tacki
8 Tacka

9 Zapamitaj kolejno

$set 14 #Toolbar

1 Zmie nazw aktywnego pulpitu
2 Tryb paska ikon
3 Wszystkie okna
4 Ikony
5 adne
6 Pulpit
7 Ikony Pulpitu
8 Warstwa Paska Narzdzi
10 Pooenie
11 Pasek Narzdzi
12 Szeroko w procentach

13 Zegar w trybie 24h
14 Zegar w trybie 12h
15 Format wywietlania zegara
16 Poka ikony

$set 15 #Window

1 Bez nazwy

$set 16 #Windowmenu

1 Zamknij
2 Minimalizuj
3 Warstwa
4 Pod spd
5 Maksymalizuj
6 Na wierzch
7 Wylij na ...
8 Zwi
9 Przyklej

10 Zakocz

$set 17 #Workspace

1 Pulpit %d
2 Pulpity
3 Nowy Pulpit
4 Usu Ostatni

$set 18 #bsetroot

1 %s: bd: musisz okreli jedno z: -solid, -mod, -gradient\n
2 Nie mog stowrzy elementw pixmap - daj sobie spokj!
3 %s 2.0: (c) 1997-2000 Brad Hughes\n\n\
-display <string>        korzystam z ekranu <nazwa ekranu>\n\
-mod <x> <y>             wzr moduu\n\
-foreground, -fg <kolor> kolor pierwszego planu moduu\n\
-background, -bg <kolor> kolor ta moduu\n\n\
-gradient <tekstura>     cieniowana tekstura\n\
-from <kolor>            pierwszy kolor cieniowania\n\
-to <kolor>              drugi kolor cieniowania\n\n\
-solid <kolor>           stay kolor\n\n\
-help                    drukuj t pomoc i wychodz\n

$set 19 #main

1 bd: '-display' wymaga argumentu\n
2 Za allokacja
4 Poza zakresem
5 Bd wykonania
6 Standardowy wyjtek
7 Nieznany bd
8 Bd: '-log' wymaga wartoci
9 Plik dziennika
10 Zapisuj dziennik
11 bd: '-rc' wymaga argumentu\n
12 Fluxbox %s: (c) %s Henrik Kinnunen\n\n\
-display <string>\t\tuyj poczenia ekranu.\n\
-rc <string>\t\t\tuyj innego pliku zasobw.\n\
-version\t\t\twywietlam wersj i wychodz.\n\
-info\t\t\t\twywietlam przydatne informacje.\n\
-log <filename>\t\t\tlogi przesyam do pliku.\n\
-help\t\t\t\twywietlam t pomoc i wychodz.\n\
13 Nie mogem ustawi zmiennej rodowiskowej 'DISPLAY'\n\n
 

$set 20 #layers

1 Powyej docku
2 Na dno
3 Pulpit
4 Dock
5 Normalna
6 Na wierzch

==> fluxbox-1.0rc2.tar.bz2: fluxbox-1.0rc2/nls/pl_PL/Translation.m <==
$ codeset=ISO-8859-2

$set 1 #Align

1 Dolny rodkowy
2 Dolny Lewy
3 Dolny Prawy
4 Poziomo
5 Z Lewej
6 Dolny Lewy
7 rodkowy Lewy
8 Grny Lewy
9 Wzgldny
10 Z Prawej
11 Dolny Prawy
12 rodkowy Prawy
13 Prawy Grny
14 Grny rodkowy
15 Grny Lewy
16 Grny Prawy
17 Pionowo

$set 2 #BaseDisplay

1 Porzucam...Zrzucam pami\n
2 Zamykam\n
3 %s:    sygna %d otrzyma\n

$set 3 #Common
1 Przeroczysto
2 Auto ukrywanie
3 Skompilowano
4 Skompilowano z opcjami
5 Kompilator
6 Wersja kompilatora
7 init
8 keys
10 menu
11 Styl
12 Wartoci domylne
13 wyczone
14 Bd
15 Fluxbox wersja
16 Maksymalizuj nad
18 Widoczny



$set 4 #Configmenu

1 AntiAlias
2 Automatyczne podnoszenie
3 Kliknij aby da na wierzch
4 Kliknij by uaktywni
5 Dekoracje na oknach-dzieciach
6 Zmiana pulpitw kkiem myszy
7 Zmie aktywne okno przy zmianie pulpitw
8 Sposb aktywacji okien
9 Ustawiaj nowe okna jako aktywne
10 Pena maksymalizacja
11 Rastrowanie Obrazu
12 Wywietlaj zawarto przesuwanego okna
13 P-automatyczna aktywacja
14 Poka kursorem by uaktywni
15 Pulpity obok siebie

16 Wymu pseudo przeroczysto
17 Przeroczysto menu
18 Przeroczysto
19 Przeroczysto aktywnego okna
20 Przeroczysto nieaktywnego okna

$set 5 #Ewmh

1 Bd krytyczny: Brak pamici, nie mog zarezerwowa lity klientw EWMH

$set 6 #FbTkError

1 Ostrzeenie! Wysoko > 3200 Ustawiam Wysoko = 3200
2 Ostrzeenie! Szeroko > 3200 Ustawiam Szeroko = 3200
3 Ostrzeenie: nie mog zaadowa zapasowej czcionki
4 Bd allokacji.
5 Bd podczas tworzenia pixmapy
6 Nie mog stworzy XImage
7 Bd odczytu
8 Ostrzeenie: Nie znaleziono poprawnych ustawie przeroczystoci
9 Ostrzeenie: Nie powiodo si tworzenie przeroczystego obrazu
10 Ostrzeenie: Nie powiodo si tworzenie przeroczystej pixmapy 
11 Nie znalaem formatu dla ekranu(%d)
12 Brak pamici
13 Brak pamici podczas alokacji niebieskiego bufora.
14 Brak pamici podczas alokacji zielonego bufora.
15 Brak pamici podczas alokacji czerwonego bufora.
16 Nie rozpoznaj elementu stylu
17 bd podczas renderowania obrazka
18 Ustawiam warto domyln

$set 7 #Fluxbox

1 niewasciwa nazwa pliku zasobw!
2 Nie mog zaadowa pliku grup
3 Nie mog zaadowa bazy danych
4 Prbuje ponownie z
5 Ostrzeenie! Nie mog znale ekranu na ktry mog zmapowa okno!
6 Nie mog utworzy katalogu %s
7 Nie moge znale ekranw do zarzdzania\nUpewnij si e nie masz wczonego inne menedera okien.
8 Bd podczas parsowania wyraenia reguralnego
9 Bd krytyczny! Moe istnie tylko jedna instancja klasy fluxbox.
10 Nie mog poczy si z serwerem X.\nUpewnij si e uruchomie X'y przed uruchomieniem Fluxbox.
11 Ostrzeenie: serwer X nie wspiera ustawie lokalnych
12 Ostrzeenie: nie mona ustawi modyfikatorw lokalnych

$set 8 #Gnome

1 Bd krytyczny: Brak pamici, nie mog zaalokowa dla listy klientw GNOME

$set 9 #Keys

1 Keys: Bd w lini
2 Keys: Bd podczas czenia drzew klawiszy!
3 Keys: Niewaciwy klawisz/modyfikator w linii

$set 10 #Menu

1 Konfiguracja
2 Domylne menu fluxbox
3 Wyjcie
4 Ikonki
5 Warstwa...
6 Na monitorze...
7 Umiejscowienie
8 Przeaduj ustawienia
9 Restart


$set 11 #Remember

1 Dekoracje
2 Rozmiar
3 Przejd do pulpitu
4 Warstwa
5 Zapamitaj
6 Pozycja
7 Zapisz przy wyjciu
8 Zwinity
9 Przyklejony
10 Nieznany klucz pliku apps
11 Pulpit

12 Monitor

$set 12 #Screen

1 BScreen::BScreen: wystpi bd podczas wysyania zapytania do serwera X'w.\nNa ekranie wczony jest ju inny meneder okien
2 S: %4d x W: %4d

3 BScreen::BScreen: uywanie ekrany %d uywam visuala 0x%lx, gboko %d\n


$set 13 #Slit

1 Klienci
2 Przesu wszystkich w gr
3 Przesu wszystkich w d
4 Kierunek Tacki
5 Warstwa
6 Na monitorze
7 Pooenie Tacki
8 Tacka

9 Zapamitaj kolejno

$set 14 #Toolbar

1 Zmie nazw aktywnego pulpitu
2 Tryb paska ikon
3 Wszystkie okna
4 Ikony
5 adne
6 Pulpit
7 Ikony Pulpitu
8 Warstwa Paska Narzdzi
10 Pooenie
11 Pasek Narzdzi
12 Szeroko w procentach

13 Zegar w trybie 24h
14 Zegar w trybie 12h
15 Format wywietlania zegara
16 Poka ikony

$set 15 #Window

1 Bez nazwy

$set 16 #Windowmenu

1 Zamknij
2 Minimalizuj
3 Warstwa
4 Pod spd
5 Maksymalizuj
6 Na wierzch
7 Wylij na ...
8 Zwi
9 Przyklej

10 Zakocz

$set 17 #Workspace

1 Pulpit %d
2 Pulpity
3 Nowy Pulpit
4 Usu Ostatni

$set 18 #fbsetroot

1 bd: musisz okreli jedno z: -solid, -mod, -gradient\n
2 Nie mog stowrzy elementw pixmap - daj sobie spokj!
3 -display <string>        korzystam z ekranu <nazwa ekranu>\n\
-mod <x> <y>             wzr moduu\n\
-foreground, -fg <kolor> kolor pierwszego planu moduu\n\
-background, -bg <kolor> kolor ta moduu\n\n\
-gradient <tekstura>     cieniowana tekstura\n\
-from <kolor>            pierwszy kolor cieniowania\n\
-to <kolor>              drugi kolor cieniowania\n\n\
-solid <kolor>           stay kolor\n\n\
-help                    drukuj t pomoc i wychodz\n

$set 19 #main

1 bd: '-display' wymaga argumentu
2 Za allokacja
4 Poza zakresem
5 Bd wykonania
6 Standardowy wyjtek
7 Nieznany bd
8 Bd: '-log' wymaga wartoci
9 Plik dziennika
10 Zapisuj dziennik
11 bd: '-rc' wymaga argumentu
13 Fluxbox %s: (c) %s Henrik Kinnunen\n\n\
-display <string>\t\tuyj poczenia ekranu.\n\
-rc <string>\t\t\tuyj innego pliku zasobw.\n\
-version\t\t\twywietlam wersj i wychodz.\n\
-info\t\t\t\twywietlam przydatne informacje.\n\
-log <filename>\t\t\tlogi przesyam do pliku.\n\
-help\t\t\t\twywietlam t pomoc i wychodz.\n\
14 Nie mogem ustawi zmiennej rodowiskowej 'DISPLAY'\n\n
 

$set 20 #layers

1 Powyej docku
2 Na dno
3 Pulpit
4 Dock
5 Normalna
6 Na wierzch
